==> intelmq-2.2.0rc1.tar.gz: intelmq-2.2.0rc1/intelmq/tests/bots/parsers/shadowserver/test_scan_ntpmonitor.py <==
# -*- coding: utf-8 -*-

import os
import unittest

import intelmq.lib.test as test
import intelmq.lib.utils as utils
from intelmq.bots.parsers.shadowserver.parser import ShadowserverParserBot

with open(os.path.join(os.path.dirname(__file__), 'testdata/scan_ntpmonitor.csv')) as handle:
    EXAMPLE_FILE = handle.read()
EXAMPLE_LINES = EXAMPLE_FILE.splitlines()

EXAMPLE_REPORT = {'feed.name': 'NTP Monitor',
                  "raw": utils.base64_encode(EXAMPLE_FILE),
                  "__type": "Report",
                  "time.observation": "2015-01-01T00:00:00+00:00",
                  "extra.file_name": "2019-01-01-scan_ntpmonitor-test-geo.csv",
                  }
EVENTS = [{'__type': 'Event',
           'feed.name': 'NTP Monitor',
           "classification.identifier": "ntp-monitor",
           "classification.taxonomy": "vulnerable",
           "classification.type": "vulnerable service",
           "extra.naics": 541690,
           "extra.packets": 1,
           "extra.sic": 874899,
           "extra.size": 440,
           "protocol.application": "ntp",
           "protocol.transport": "udp",
           'raw': utils.base64_encode('\n'.join([EXAMPLE_LINES[0],
                                                 EXAMPLE_LINES[1]])),
           "source.asn": 3320,
           "source.geolocation.cc": "DE",
           "source.geolocation.city": "DUSSELDORF",
           "source.geolocation.region": "NORDRHEIN-WESTFALEN",
           "source.ip": "198.51.100.4",
           "source.port": 123,
           "source.reverse_dns": "198-51-100-4.example.net",
           "time.observation": "2015-01-01T00:00:00+00:00",
           "time.source": "2016-07-24T06:09:09+00:00"
           },
           {'__type': 'Event',
           'feed.name': 'NTP Monitor',
           "classification.identifier": "ntp-monitor",
           "classification.taxonomy": "vulnerable",
           "classification.type": "vulnerable service",
           "extra.naics": 541690,
           "extra.packets": 1,
           "extra.sic": 874899,
           "extra.size": 224,
           "protocol.application": "ntp",
           "protocol.transport": "udp",
           'raw': utils.base64_encode('\n'.join([EXAMPLE_LINES[0],
                                                 EXAMPLE_LINES[2]])),
           "source.asn": 3320,
           "source.geolocation.cc": "DE",
           "source.geolocation.city": "BOCHUM",
           "source.geolocation.region": "NORDRHEIN-WESTFALEN",
           "source.ip": "198.51.100.182",
           "source.port": 123,
           "source.reverse_dns": "198-51-100-182.example.net",
           "time.observation": "2015-01-01T00:00:00+00:00",
           "time.source": "2016-07-24T06:09:28+00:00"
           },
          ]

class TestShadowserverParserBot(test.BotTestCase, unittest.TestCase):
    """
    A TestCase for a ShadowserverParserBot.
    """

    @classmethod
    def set_bot(cls):
        cls.bot_reference = ShadowserverParserBot
        cls.default_input_message = EXAMPLE_REPORT

    def test_event(self):
        """ Test if correct Event has been produced. """
        self.run_bot()
        for i, EVENT in enumerate(EVENTS):
            self.assertMessageEqual(i, EVENT)


if __name__ == '__main__':  # pragma: no cover
    unittest.main()

==> intelmq-3.0.2-post1.tar.gz: intelmq-3.0.2/intelmq/tests/bots/parsers/shadowserver/test_scan_ntpmonitor.py <==
# SPDX-FileCopyrightText: 2019 Guillermo Rodriguez
#
# SPDX-License-Identifier: AGPL-3.0-or-later

# -*- coding: utf-8 -*-

import os
import unittest

import intelmq.lib.test as test
import intelmq.lib.utils as utils
from intelmq.bots.parsers.shadowserver.parser import ShadowserverParserBot

with open(os.path.join(os.path.dirname(__file__), 'testdata/scan_ntpmonitor.csv')) as handle:
    EXAMPLE_FILE = handle.read()
EXAMPLE_LINES = EXAMPLE_FILE.splitlines()

EXAMPLE_REPORT = {'feed.name': 'NTP Monitor',
                  "raw": utils.base64_encode(EXAMPLE_FILE),
                  "__type": "Report",
                  "time.observation": "2015-01-01T00:00:00+00:00",
                  "extra.file_name": "2019-01-01-scan_ntpmonitor-test-geo.csv",
                  }
EVENTS = [{'__type': 'Event',
           'feed.name': 'NTP Monitor',
           "classification.identifier": "ntp-monitor",
           "classification.taxonomy": "vulnerable",
           "classification.type": "vulnerable-system",
           "extra.naics": 541690,
           "extra.packets": 1,
           "extra.sic": 874899,
           "extra.size": 440,
           "protocol.application": "ntp",
           "protocol.transport": "udp",
           'raw': utils.base64_encode('\n'.join([EXAMPLE_LINES[0],
                                                 EXAMPLE_LINES[1]])),
           "source.asn": 3320,
           "source.geolocation.cc": "DE",
           "source.geolocation.city": "DUSSELDORF",
           "source.geolocation.region": "NORDRHEIN-WESTFALEN",
           "source.ip": "198.51.100.4",
           "source.port": 123,
           "source.reverse_dns": "198-51-100-4.example.net",
           "time.observation": "2015-01-01T00:00:00+00:00",
           "time.source": "2016-07-24T06:09:09+00:00"
           },
           {'__type': 'Event',
           'feed.name': 'NTP Monitor',
           "classification.identifier": "ntp-monitor",
           "classification.taxonomy": "vulnerable",
           "classification.type": "vulnerable-system",
           "extra.naics": 541690,
           "extra.packets": 1,
           "extra.sic": 874899,
           "extra.size": 224,
           "protocol.application": "ntp",
           "protocol.transport": "udp",
           'raw': utils.base64_encode('\n'.join([EXAMPLE_LINES[0],
                                                 EXAMPLE_LINES[2]])),
           "source.asn": 3320,
           "source.geolocation.cc": "DE",
           "source.geolocation.city": "BOCHUM",
           "source.geolocation.region": "NORDRHEIN-WESTFALEN",
           "source.ip": "198.51.100.182",
           "source.port": 123,
           "source.reverse_dns": "198-51-100-182.example.net",
           "time.observation": "2015-01-01T00:00:00+00:00",
           "time.source": "2016-07-24T06:09:28+00:00"
           },
          ]

class TestShadowserverParserBot(test.BotTestCase, unittest.TestCase):
    """
    A TestCase for a ShadowserverParserBot.
    """

    @classmethod
    def set_bot(cls):
        cls.bot_reference = ShadowserverParserBot
        cls.default_input_message = EXAMPLE_REPORT

    def test_event(self):
        """ Test if correct Event has been produced. """
        self.run_bot()
        for i, EVENT in enumerate(EVENTS):
            self.assertMessageEqual(i, EVENT)


if __name__ == '__main__':  # pragma: no cover
    unittest.main()
